@@ -25,6 +25,7 @@ from sphinx.util.nodes import nested_parse_with_titles
 
 from oslo_config import cfg
 from oslo_config import generator
+import oslo_i18n
 
 import six
 
@@ -72,6 +73,11 @@ _TYPE_DESCRIPTIONS = {
     cfg.ListOpt: 'list',
     cfg.DictOpt: 'dict',
     cfg.MultiStrOpt: 'multi-valued',
+    cfg.IPOpt: 'ip address',
+    cfg.PortOpt: 'port number',
+    cfg.HostnameOpt: 'hostname',
+    cfg.URIOpt: 'URI',
+    cfg.HostAddressOpt: 'host address',
     cfg._ConfigFileOpt: 'list of filenames',
     cfg._ConfigDirOpt: 'list of directory names',
 }
@@ -139,6 +145,13 @@ def _format_group(app, namespace, group_name, group_obj, opt_list):
             else:
                 warnings.warn('Failed to fully format sample for %s: %s' %
                               (opt.dest, err))
+        if opt.advanced:
+            yield _indent(
+                ':Advanced Option: intended for advanced users and not used',)
+            yield _indent(
+                ':by the majority of users, and might have a significant',)
+            yield _indent(
+                ':effect on stability and/or performance.',)
         yield ''
 
         try:
@@ -154,14 +167,18 @@ def _format_group(app, namespace, group_name, group_obj, opt_list):
         if opt.deprecated_opts:
             for line in _list_table(
                     ['Group', 'Name'],
-                    ((d.group or 'DEFAULT',
+                    ((d.group or group_name,
                       d.name or opt.dest or 'UNSET')
                      for d in opt.deprecated_opts),
                     title='Deprecated Variations'):
                 yield _indent(line)
         if opt.deprecated_for_removal:
             yield _indent('.. warning::')
-            yield _indent('   This option is deprecated for removal.')
+            if opt.deprecated_since:
+                yield _indent('   This option is deprecated for removal '
+                              'since %s.' % opt.deprecated_since)
+            else:
+                yield _indent('   This option is deprecated for removal.')
             yield _indent('   Its value may be silently ignored ')
             yield _indent('   in the future.')
             yield ''
@@ -428,5 +445,14 @@ class ConfigDomain(Domain):
 
 
 def setup(app):
+    # NOTE(dhellmann): Try to turn off lazy translation from oslo_i18n
+    # so any translated help text or deprecation messages associated
+    # with configuration options are treated as regular strings
+    # instead of Message objects. Unfortunately this is a bit
+    # order-dependent, and so it's still possible that importing code
+    # from another module such as through the autodoc features, or
+    # even through the plugin scanner, will turn lazy evaluation back
+    # on.
+    oslo_i18n.enable_lazy(False)
     app.add_directive('show-options', ShowOptionsDirective)
     app.add_domain(ConfigDomain)
